@@ -22,11 +22,12 @@
 #endif
 
 #define NB_VERSION_MAJOR 2
-#define NB_VERSION_MINOR 2
-#define NB_VERSION_PATCH 0
+#define NB_VERSION_MINOR 6
+#define NB_VERSION_PATCH 1
 #define NB_VERSION_DEV   0 // A value > 0 indicates a development release
 
 // Core C++ headers that nanobind depends on
+#include <cstddef>
 #include <cstdint>
 #include <exception>
 #include <stdexcept>
@@ -36,6 +37,7 @@
 #include <new>
 
 // Implementation. The nb_*.h files should only be included through nanobind.h
+// IWYU pragma: begin_exports
 #include "nb_python.h"
 #include "nb_defs.h"
 #include "nb_enums.h"
@@ -52,6 +54,7 @@
 #include "nb_call.h"
 #include "nb_func.h"
 #include "nb_class.h"
+// IWYU pragma: end_exports
 
 #if defined(_MSC_VER)
 #  pragma warning(pop)
