@@ -334,7 +334,7 @@ public:
 };
 
 class capsule : public object {
-    NB_OBJECT_DEFAULT(capsule, object, "types.CapsuleType", PyCapsule_CheckExact)
+    NB_OBJECT_DEFAULT(capsule, object, NB_TYPING_CAPSULE, PyCapsule_CheckExact)
 
     capsule(const void *ptr, void (*cleanup)(void *) noexcept = nullptr) {
         m_ptr = detail::capsule_new(ptr, nullptr, cleanup);
@@ -371,10 +371,12 @@ class int_ : public object {
         : object(detail::int_from_obj(h.ptr()), detail::steal_t{}) { }
 
     template <typename T, detail::enable_if_t<std::is_arithmetic_v<T>> = 0>
-    explicit int_(T value)
-        : object(
-              detail::type_caster<T>::from_cpp(value, rv_policy::copy, nullptr),
-              detail::steal_t{}) {
+    explicit int_(T value) {
+        if constexpr (std::is_floating_point_v<T>)
+            m_ptr = PyLong_FromDouble((double) value);
+        else
+            m_ptr = detail::type_caster<T>::from_cpp(value, rv_policy::copy, nullptr).ptr();
+
         if (!m_ptr)
             raise_python_error();
     }
@@ -462,7 +464,8 @@ class bytearray : public object {
 
     const char *c_str() const { return PyByteArray_AsString(m_ptr); }
 
-    const void *data() const { return (const void *) PyByteArray_AsString(m_ptr); }
+    const void *data() const { return PyByteArray_AsString(m_ptr); }
+    void *data() { return PyByteArray_AsString(m_ptr); }
 
     size_t size() const { return (size_t) PyByteArray_Size(m_ptr); }
 
